/** @file
 * @brief Config class header. This class represents the actual configuration.
 *
 *
 *
 * @copyright Intra2net AG
 * @license GPLv2
*/

#ifndef CONFIG_H
#define CONFIG_H

#include <string>

#include "service.h"
#include "logger.h"

#include <boost/program_options.hpp>
#include <boost/shared_ptr.hpp>


class Config
{
private:

    typedef boost::shared_ptr<boost::program_options::options_description> Options_descriptionPtr;

    Options_descriptionPtr OptDescCmd;
    Options_descriptionPtr OptDescConfMain;
    Options_descriptionPtr OptDescConfService;

    boost::program_options::variables_map VariablesMap;

    std::list<Service::Ptr> Services;         // Represents all active Services.
    std::list<Service::Ptr> OldServices;     // Represents all old Services where the timeout isn't expired (in case the same Service is redefined).

    Logger::Ptr Log;

    bool DaemonMode;
    int Loglevel;
    bool Syslog;
    std::string ConfigPath;
    bool EnableIPv6;
    std::string WebcheckIpUrl;
    std::string WebcheckIpUrlAlt;

    Service::Ptr create_service(const std::string&,const std::string&,const std::string&,const std::string&, const int, const int);
    int load_main_config_file(const std::string&);
    int load_service_config_file(const std::string&);
    std::string to_lower(std::string) const;

public:

    typedef boost::shared_ptr<Config> Ptr;

    Config(Logger::Ptr);

    ~Config();

    int serialize_services();

    int deserialize_services();

    int parse_cmd_line(int, char **);

    int load_config_from_files();

    std::list<Service::Ptr> get_services() const;

    Options_descriptionPtr get_opt_desc_cmd() const;

    Options_descriptionPtr get_opt_desc_conf_main() const;

    Options_descriptionPtr get_opt_desc_conf_service() const;

    bool get_daemon_mode() const;

    void delete_services();

    int get_loglevel() const;

    bool get_syslog() const;

    bool get_enable_ipv6() const;

    std::string get_webcheck_ip_url() const;

    std::string get_webcheck_ip_url_alt() const;

    void delete_variables_map();

};

#endif
