/** @file
 * @brief DHS Service class implementation. This class represents the DHS service.
 *
 *
 *
 * @copyright Intra2net AG
 * @license GPLv2
*/

#include "dhs.h"

#include <time.h>

using namespace std;


/**
 * Default Constructor, needed for object serialization.
 */
DHS::DHS()
{
}


/**
 * Constructor.
 * @param _hostname The hostname to update
 * @param _login The login name.
 * @param _password The corresponding password.
 */
DHS::DHS(const string& _protocol, const string& _hostname, const string& _login, const string& _password, const Logger::Ptr& _logger, const int _update_interval, const int _max_updates_within_interval)
{
    if ( _update_interval == -1 )        // If _update_interval is default po::option_desc (not specified via config)
        set_update_interval(0);              // use default protocol value
    else
        set_update_interval(_update_interval);

    if ( _max_updates_within_interval == -1 )
        set_max_updates_within_interval(0);
    else
        set_max_updates_within_interval(_max_updates_within_interval);

    set_protocol(_protocol);
    set_hostname(_hostname);
    set_login(_login);
    set_password(_password);
    set_logger(_logger);
}


/**
 * Default destructor
 */
DHS::~DHS()
{
}


/**
 * Service update method which should implement the corresponding service protocol.
 * @param ip The new ip to set for the hostname.
 */
void DHS::update(const string& ip)
{
    // If actual service ip (ip set in last update) differs present host ip, then update
    if ( get_actual_ip() != ip )
    {
        get_logger()->print_update_service("DHS");

        if ( perform_update(ip) == 0 )
        {
            // if update was successful, we need to set the Lastupdated and ActualIP base member.
            get_last_updates()->push_front(time(NULL));
            set_actual_ip(ip);
            get_logger()->print_update_service_successful("DHS");
        }
        else
        {
            // problem while trying to update service
            // TODO: error logging
        }
    }
}


/**
 * Performs the Service update.
 * @param ip IP Address to set.
 * @return 0 if all is fine, -1 otherwise.
 */
int DHS::perform_update(const std::string& ip)
{
    return 0;
}


/**
 * Serialize function needed by boost/serialization to define which members should be stored as the object state.
 * @param ar Archive
 * @param version Version
 */
template<class Archive>
void DHS::serialize(Archive & ar, const unsigned int version)
{
    ar & boost::serialization::base_object<Service>(*this);
}
