/** @file
 * @brief IPHelper class header. This class represents a Helper to get the actual IP.
 *
 *
 *
 * @copyright Intra2net AG
 * @license GPLv2
*/

#ifndef IPHELPER_H
#define IPHELPER_H

#include "logger.h"

#include <boost/shared_ptr.hpp>
#include <curl/curl.h>

/**
	@author Bjoern Sikora <bjoern.sikora@intra2net.com>
*/
class IPHelper
{
private:
    std::string Hostname;
    std::string WebcheckIpUrl;
    std::string WebcheckIpUrlAlt;

    bool UseIPv6;

    Logger::Ptr Log;

public:

    typedef boost::shared_ptr<IPHelper> Ptr;

    IPHelper();

    IPHelper(const Logger::Ptr, const std::string&, const std::string&, const bool);

    ~IPHelper();

    std::string get_actual_ip() const;

    std::string dns_query() const;

    std::string webcheck_ip() const;

    // libcurl is a C library, so we have to make the callback member function static :-(
    static int http_receive( char *, size_t, size_t, std::string* );

    CURL * init_curl(std::string&, char*) const;

    void set_curl_url(CURL *, const std::string&) const;

    int perform_curl_operation(CURL *, char*, const std::string&) const;

    std::string parse_ip(const std::string&) const;
};

#endif
