/** @file
 * @brief Logger class header. This class represents the Logging facility.
 *
 *
 *
 * @copyright Intra2net AG
 * @license GPLv2
*/

#ifndef LOGGER_H
#define LOGGER_H

#include <string>

#include <boost/program_options.hpp>
#include <boost/shared_ptr.hpp>

class Logger
{

private:

    typedef boost::shared_ptr<boost::program_options::options_description> Options_descriptionPtr;

    int Loglevel;
    bool Syslog;

public:

    typedef boost::shared_ptr<Logger> Ptr;

    Logger();

    ~Logger();

    void log_notice(const std::string&) const;

    void log_warning(const std::string&) const;

    void log_error(const std::string&) const;

    void set_loglevel(const int);

    int get_loglevel() const;

    void set_syslog(const bool);

    bool get_syslog() const;

    void set_log_facility(const int, const bool);

    void print_usage(const Options_descriptionPtr) const;

    void print_version() const;

    void print_cmd_parsed() const;

    void print_conf_files_parsed() const;

    void print_destructor_call(const std::string&) const;

    void print_constructor_call(const std::string&) const;

    void print_update_service(const std::string&) const;

    void print_unknown_cmd_option(const std::string&) const;

    void print_unknown_protocol(const std::string&) const;

    void print_load_service_conf(const std::string&) const;

    void print_load_main_conf(const std::string&) const;

    void print_unknown_service_conf_option(const std::string&) const;

    void print_unknown_main_conf_option(const std::string&) const;

    void print_error_opening_r(const std::string&) const;

    void print_error_opening_rw(const std::string&) const;

    void print_error_config_path(const std::string&) const;

    void print_conf_loaded(const std::string&) const;

    void print_conf_not_loaded(const std::string&) const;

    void print_missing_cmd_service_option() const;

    void print_runnig_as_daemon(const int) const;

    void print_daemon_mode(const bool) const;

    void print_error_fork() const;

    void print_pid_found(const int) const;

    void print_process_already_running(const int) const;

    void print_caught_sigterm() const;

    void print_caught_siguser1() const;

    void print_caught_sighup() const;

    void print_error_setting_signal(const std::string&) const;

    void print_init_log_facility() const;

    void print_offline_mode() const;

    void print_serialized_objects_success() const;

    void print_deserialized_objects_success() const;

    void print_service_object(const std::string&, const std::string&, const std::string&, const std::string&, const std::string&, const int, const int, const std::string&, std::list<int>*) const;

    void print_exception_serialize(const std::string&) const;

    void print_exception_deserialize(const std::string&) const;

    void print_error_kill_child(const int) const;

    void print_child_killed(const int) const;

    void print_no_object_file(const std::string&) const;

    void print_hostname(const std::string&) const;

    void print_own_ipv4(const std::string&) const;

    void print_own_ipv6(const std::string&) const;

    void print_error_hostname_to_ip(const std::string&, const std::string&) const;

    void print_update_service_successful(const std::string&) const;

    void print_webcheck_no_ip() const;

    void print_webcheck_url_connection_problem(const char *, const std::string&) const;

    void print_webcheck_error(const char *, const std::string&) const;

    void print_received_curl_data(const std::string&) const;

    void print_regex_found_ip(const std::string&) const;

    void print_regex_ip_not_found(const std::string&) const;

    void print_multiple_cmd_option(const std::string&) const;

    void print_update_not_allowed(const int current_time, const int old_time, const int MaxUpdatesWithinInterval, const std::string& service) const;

    void print_update_service_failure(const std::string& service) const;
};

#endif
