/** @file
 * @brief The abstract service class. This class represents all services.
 *
 *
 *
 * @copyright Intra2net AG
 * @license GPLv2
*/

#ifndef SERVICE_H
#define SERVICE_H

#include "logger.h"

#include <string>

#include <boost/serialization/array.hpp>
#include <boost/shared_ptr.hpp>


class Service
{
private:

    std::string Protocol;
    std::string Hostname;

    std::string Login;
    std::string Password;

    std::string ActualIP;

    int UpdateInterval;
    int MaxUpdatesWithinInterval;

    std::list<int> LastUpdates;

    friend class boost::serialization::access;
    template<class Archive>
    void serialize(Archive &, const unsigned int);

    Logger::Ptr Log;

public:

    typedef boost::shared_ptr<Service> Ptr;

    Service();

    virtual ~Service();

    virtual void update(const std::string&) = 0;

    int get_update_interval()const;
    void set_update_interval(const int);

    int get_max_updates_within_interval() const;
    void set_max_updates_within_interval(const int);

    void set_protocol(const std::string&);
    std::string get_protocol() const;

    void set_hostname(const std::string&);
    std::string get_hostname() const;

    void set_login(const std::string&);
    std::string get_login() const;

    void set_password(const std::string&);
    std::string get_password() const;

    void set_last_updates(std::list<int>*);
    std::list<int>* get_last_updates();

    void set_actual_ip(const std::string&);
    std::string get_actual_ip() const;

    void set_logger(const Logger::Ptr&);
    Logger::Ptr get_logger() const;

    bool update_allowed(const int current_time);

    bool operator== (const Service&) const;
    bool operator!= (const Service&) const;
};

#endif
