/** @file
 * @brief Serviceholder class implementation. This class holds Service objects in a list for serialization.
 *
 *
 *
 * @copyright Intra2net AG
 * @license GPLv2
*/

#include "serviceholder.h"

#include <boost/serialization/list.hpp>

using namespace std;


/**
 * Default constructor. Invoked on serialization and deserialization.
 */
Serviceholder::Serviceholder()
{
}


/**
 * Default destructor. While serializing and deserializing we use boost/shared_ptr, the resources are managed correctly.
 */
Serviceholder::~Serviceholder()
{
}


/**
 * Serialize function needed by boost/serialization to define which members should be stored as the object state.
 * In this case the STL list of Service pointers will be serialized.
 * @param ar Archive
 * @param version Version
 */
template<class Archive>
void Serviceholder::serialize(Archive & ar, const unsigned int version)
{
    ar & HoldServices;
}


/**
 * Add Service * to internal list.
 * @param service Pointer to Service object.
 */
void Serviceholder::add_service(Service::Ptr service)
{
    HoldServices.push_back(service);
}


/**
 * Needed after deserialization to get the valid list of Service* back.
 * @return The list of Service*.
 */
std::list<Service::Ptr> Serviceholder::get_hold_services() const
{
    return HoldServices;
}
