/** @file
 * @brief The updater class header. This class represents the updater logic.
 *
 *
 *
 * @copyright Intra2net AG
 * @license GPLv2
*/

#ifndef UPDATER_H
#define UPDATER_H

#include "config.h"
#include "logger.h"
#include "iphelper.h"

#include <boost/shared_ptr.hpp>


class Updater
{

private:

    Config::Ptr Conf;
    Logger::Ptr Log;
    IPHelper::Ptr IPHelp;

public:

    typedef boost::shared_ptr<Updater> Ptr;

    Updater();

    ~Updater();

    void update_services();

    int init_config_from_cmd(int, char **);

    int init_config_from_files();

    Config::Ptr get_config() const;

    Logger::Ptr get_logger() const;

    int reload_config();

    void init_log_facility();

    int init_ip_helper();
};

#endif
